@@ -18,8 +18,9 @@ class EventVoteView(CustomModelViewSet):
 
     filterset_fields = {
         'title': ['contains'],
-        '_type': ['exact'],
         'event_id': ['exact'],
+        'schedule_id': ['exact'],
+
     }
 
     def create(self, request, *args, **kwargs):
@@ -39,21 +40,46 @@ class EventVoteView(CustomModelViewSet):
             headers = self.get_success_headers(serializer.data)
             return Response(serializer.data, status=status.HTTP_201_CREATED, headers=headers)
 
-    def list(self, request, *args, **kwargs):
-        event_id = request.query_params.get('event_id', None)
-        queryset = self.model_class.objects.filter(event_id=event_id).first()
-        serializer = self.get_serializer(queryset)
-        return Response(serializer.data)
-
 
 class EventVoteUserView(CustomModelViewSet):
     model_class = EventVoteUser
     serializer_class = EventVoteUserSerializer
 
     filterset_fields = {
-        'event_id': ['exact']
+        'event_id': ['exact'],
+        'schedule_id': ['exact'],
     }
 
+    def create(self, request, *args, **kwargs):
+        serializer = self.get_serializer(data=request.data)
+        serializer.is_valid(raise_exception=True)
+        self.perform_create(serializer)
+        response_data = serializer.data
+        qa = response_data['qa']
+        EventVote_queryset = EventVote.objects.get(pk=response_data['qa_id'])
+        for index, qa_item in enumerate(qa):
+            if qa_item['qa_type'] in [1, 2]:
+                option_sum = 0  # 选择总数
+                option_list = list()  # 每个选项数
+                for option_index, qa_option in enumerate(qa_item['option']):
+                    count = 0
+                    qa_data = self.model_class.objects.filter(
+                        qa_id=response_data['qa_id'])
+                    for item in qa_data:
+                        if item.qa[index]['option'][option_index]['checked'] == 1:
+                            count += 1
+                    option_list.append(count)
+
+                    option_sum += count
+                for option_index, option_item in enumerate(option_list):
+                    rate = round(float(option_item / option_sum), 2)
+                    EventVote_queryset.qa[index]['option'][option_index]['rate'] = rate
+                    EventVote_queryset.save()
+                    response_data['qa'][index]['option'][option_index]['rate'] = rate
+
+        headers = self.get_success_headers(response_data)
+        return Response(response_data, status=status.HTTP_201_CREATED, headers=headers)
+
     def list(self, request, *args, **kwargs):
         event_id = request.query_params.get('event_id', None)
         openid = jwt_get_openid_handler(request.auth)
